==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/IncludeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.usecase.Include;
import io.ciera.tool.sql.ooaofooa.usecase.IncludeSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.UseCaseAssociationSetImpl;

import java.util.Arrays;
import java.util.List;


public class IncludeSetImpl extends InstanceSet<IncludeSet,Include> implements IncludeSet {

    // attributes
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( Include include : this ) include.setAssoc_ID( ref_Assoc_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( Include include : this ) include.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public UseCaseAssociationSet R1210_is_a_UseCaseAssociation() throws XtumlException {
        UseCaseAssociationSet usecaseassociationset = new UseCaseAssociationSetImpl();
        for ( Include include : this ) usecaseassociationset.add( include.R1210_is_a_UseCaseAssociation() );
        return usecaseassociationset;
    }


    @Override
    public Include nullElement() {
        return IncludeImpl.EMPTY_INCLUDE;
    }

    @Override
    public IncludeSet emptySet() {
      return new IncludeSetImpl();
    }

    @Override
    public IncludeSet value() {
        return this;
    }

    @Override
    public List<Include> elements() {
        return Arrays.asList(toArray(new Include[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/IncludeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.usecase.Include;
import io.ciera.tool.sql.ooaofooa.usecase.IncludeSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.UseCaseAssociationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class IncludeSetImpl extends InstanceSet<IncludeSet,Include> implements IncludeSet {

    public IncludeSetImpl() {
    }

    public IncludeSetImpl(Comparator<? super Include> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( Include include : this ) include.setAssoc_ID( ref_Assoc_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( Include include : this ) include.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public UseCaseAssociationSet R1210_is_a_UseCaseAssociation() throws XtumlException {
        UseCaseAssociationSet usecaseassociationset = new UseCaseAssociationSetImpl();
        for ( Include include : this ) usecaseassociationset.add( include.R1210_is_a_UseCaseAssociation() );
        return usecaseassociationset;
    }


    @Override
    public Include nullElement() {
        return IncludeImpl.EMPTY_INCLUDE;
    }

    @Override
    public IncludeSet emptySet() {
      return new IncludeSetImpl();
    }

    @Override
    public IncludeSet emptySet(Comparator<? super Include> comp) {
      return new IncludeSetImpl(comp);
    }

    @Override
    public IncludeSet value() {
        return this;
    }

    @Override
    public List<Include> elements() {
        return Arrays.asList(toArray(new Include[0]));
    }

}
